#
# spec file for package python-jellyfish
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jellyfish
Version:        1.0.3
Release:        1.2
Summary:        A library for doing approximate and phonetic matching of strings
License:        BSD-2-Clause
URL:            http://github.com/jamesturk/jellyfish
Source0:        https://files.pythonhosted.org/packages/source/j/jellyfish/jellyfish-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module maturin}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Jellyfish is a python library for doing approximate and phonetic
matching of strings.

Includes algorithms for string comparison: Levenshtein Distance,
Damerau-Levenshtein Distance, Jaro Distance, Jaro-Winkler Distance,
Match Rating Approach Comparison and Hamming Distance.

And algorithms for phonetic encoding: American Soundex, Metaphone,
NYSIIS (New York State Identification and Intelligence System) and
Match Rating Codex.

%prep
%autosetup -p1 -n jellyfish-%{version} -a1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.md docs/*
%{python_sitearch}/jellyfish
%{python_sitearch}/jellyfish-%{version}.dist-info

%changelog
* Thu Feb 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.3:
  * `match_rating_codex` now raises a `ValueError` when passed non-alpha
    characters (#200)
  * fully remove deprecated names
  * fully drop Python 3.7 support
  * switch to using `ahash` for Damerau-Levenshtein for speed gains
  * switched to using Rust implementation for all algorithms
  * removed rarely-used `porter_stem` function, better implementations exist
  * support for Python 3.10+
  * handle spaces correctly in MRA algorithm
  * fix buffer overflow in NYSIIS
  * safer allocations from CJellyfish
  * fix for jaro winkler (cjellyfish#8)
- Stop using greedy globs in %%files.
- Switch to autosetup and pyproject macros.
- Sprinkle in cargo_vendor due to including rust code.
* Wed Jun 17 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.8.2:
  * fix jaro_winkler/jaro_winkler_similarity mix-up
  * deprecate jaro_distance in favor of jaro_similarity
    backwards compatible shim left in place, will be removed in 1.0
  * rename jaro_winkler to jaro_winkler_similarity to match other functions
    backwards compatible shim added, but will be removed in 1.0
  * fix soundex bug with W/H cases, #83
  * fix metaphone bug with WH prefix, #108
  * fix C match rating codex bug with duplicate letters, #121
  * fix metaphone bug with leading vowels and 'kn' pair, #123
  * fix Python jaro_winkler bug #124
  * fix Python 3.9 deprecation warning
  * add manylinux wheels
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.2:
  * fix CJellyfish damerau_levenshtein w/ unicode, thanks to immerrr
  * fix final H in NYSIIS
  * fix issue w/ trailing W in metaphone
* Wed Apr  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * drop Python 2 compatibility & legacy code
  * add bugfix for NYSIIS for words starting with PF
  * restrict install to Python >= 3.4
* Thu Aug  2 2018 tchvatal@suse.com
- Version update to 0.6.1:
  * Various unicode fixes
* Mon Apr 10 2017 alarrosa@suse.com
- Use singlespec macros
* Thu Jan 19 2017 alarrosa@suse.com
- Initial release
